==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/link/lang/nb.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'nb', {
	acccessKey: 'Aksessknapp',
	advanced: 'Avansert',
	advisoryContentType: 'Type',
	advisoryTitle: 'Tittel',
	anchor: {
		toolbar: 'Sett inn/Rediger anker',
		menu: 'Egenskaper for anker',
		title: 'Egenskaper for anker',
		name: 'Ankernavn',
		errorName: 'Vennligst skriv inn ankernavnet',
		remove: 'Fjern anker'
	},
	anchorId: 'Element etter ID',
	anchorName: 'Anker etter navn',
	charset: 'Lenket tegnsett',
	cssClasses: 'Stilarkklasser',
	emailAddress: 'E-postadresse',
	emailBody: 'Melding',
	emailSubject: 'Meldingsemne',
	id: 'Id',
	info: 'Lenkeinfo',
	langCode: 'Språkkode',
	langDir: 'Språkretning',
	langDirLTR: 'Venstre til høyre (VTH)',
	langDirRTL: 'Høyre til venstre (HTV)',
	menu: 'Rediger lenke',
	name: 'Navn',
	noAnchors: '(Ingen anker i dokumentet)',
	noEmail: 'Vennligst skriv inn e-postadressen',
	noUrl: 'Vennligst skriv inn lenkens URL',
	other: '<annen>',
	popupDependent: 'Avhenging (Netscape)',
	popupFeatures: 'Egenskaper for popup-vindu',
	popupFullScreen: 'Fullskjerm (IE)',
	popupLeft: 'Venstre posisjon',
	popupLocationBar: 'Adresselinje',
	popupMenuBar: 'Menylinje',
	popupResizable: 'Skalerbar',
	popupScrollBars: 'Scrollbar',
	popupStatusBar: 'Statuslinje',
	popupToolbar: 'Verktøylinje',
	popupTop: 'Topp-posisjon',
	rel: 'Relasjon (rel)',
	selectAnchor: 'Velg et anker',
	styles: 'Stil',
	tabIndex: 'Tabindeks',
	target: 'Mål',
	targetFrame: '<ramme>',
	targetFrameName: 'Målramme',
	targetPopup: '<popup-vindu>',
	targetPopupName: 'Navn på popup-vindu',
	title: 'Lenke',
	toAnchor: 'Lenke til anker i teksten',
	toEmail: 'E-post',
	toUrl: 'URL',
	toolbar: 'Sett inn/Rediger lenke',
	type: 'Lenketype',
	unlink: 'Fjern lenke',
	upload: 'Last opp'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/nb.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'nb', {
	acccessKey: 'Aksessknapp',
	advanced: 'Avansert',
	advisoryContentType: 'Type',
	advisoryTitle: 'Tittel',
	anchor: {
		toolbar: 'Anker',
		menu: 'Rediger anker',
		title: 'Egenskaper for anker',
		name: 'Ankernavn',
		errorName: 'Vennligst skriv inn ankernavnet',
		remove: 'Fjern anker'
	},
	anchorId: 'Element etter ID',
	anchorName: 'Anker etter navn',
	charset: 'Lenket tegnsett',
	cssClasses: 'Stilarkklasser',
	download: 'Tving nedlasting',
	displayText: 'Tekst som skal vises',
	emailAddress: 'E-postadresse',
	emailBody: 'Melding',
	emailSubject: 'Meldingsemne',
	id: 'Id',
	info: 'Lenkeinfo',
	langCode: 'Språkkode',
	langDir: 'Språkretning',
	langDirLTR: 'Venstre til høyre (LTR)',
	langDirRTL: 'Høyre til venstre (RTL)',
	menu: 'Rediger lenke',
	name: 'Navn',
	noAnchors: '(Ingen anker i dokumentet)',
	noEmail: 'Vennligst skriv inn e-postadressen',
	noUrl: 'Vennligst skriv inn lenkens URL',
	noTel: 'Please type the phone number', // MISSING
	other: '<annen>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Avhenging (Netscape)',
	popupFeatures: 'Egenskaper for popup-vindu',
	popupFullScreen: 'Fullskjerm (IE)',
	popupLeft: 'Venstre posisjon',
	popupLocationBar: 'Adresselinje',
	popupMenuBar: 'Menylinje',
	popupResizable: 'Skalerbar',
	popupScrollBars: 'Scrollbar',
	popupStatusBar: 'Statuslinje',
	popupToolbar: 'Verktøylinje',
	popupTop: 'Topp-posisjon',
	rel: 'Relasjon (rel)',
	selectAnchor: 'Velg et anker',
	styles: 'Stil',
	tabIndex: 'Tabindeks',
	target: 'Mål',
	targetFrame: '<ramme>',
	targetFrameName: 'Målramme',
	targetPopup: '<popup-vindu>',
	targetPopupName: 'Navn på popup-vindu',
	title: 'Lenke',
	toAnchor: 'Lenke til anker i teksten',
	toEmail: 'E-post',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Lenke',
	type: 'Lenketype',
	unlink: 'Fjern lenke',
	upload: 'Last opp'
} );
